package afterburner.view.util
{
	import net.pixlib.load.PXXMLLoader;
	import net.pixlib.load.PXGraphicLoader;
	import net.pixlib.load.PXLoaderLocator;
	import net.pixlib.quick.PXQuick;

	import flash.utils.Dictionary;
	import flash.display.Bitmap;
	
	import starling.textures.Texture;
	
	
	/**
	 * Contient tous les éléments nécessaires pour Starling Framework.
	 * 
	 * @author Matthieu
	 */
	public class Assets
	{		
		
		private var sTextures : Dictionary = new Dictionary();// Mise en cache des Textures		
		private var aSoundUrl:Dictionary;// contient les urls de tous les sons joués dans le jeu
		
		
		// le singleton
		private static var allowInstance : Boolean = false;// empêche l'instanciation de la classe à partir du constructeur
		private static var _oInstance : Assets = null;// contient l'instance unique de la classe
		
		
		/**
		 * Constructeur.
		 * 
		 */
		public function Assets()
		{
			if (!allowInstance)// test s'il est possible d'instancier la classe
			{
				PXQuick.debug("This class cannot be instantiated from the constructor ", this);
				// throw new Error ('This class cannot be instantiated from the constructor');
			}
			else
				this.init();
		}


		/**
		 * Initialisation de la classe.
		 * 
		 */
		private function init() : void
		{
			aSoundUrl = new Dictionary();
			aSoundUrl["background"] = "assets/sound/background.mp3";
			aSoundUrl["lazerLaunch1"] = "assets/sound/lazerLaunch4.mp3";
			aSoundUrl["lazerLaunch2"] = "assets/sound/lazerLaunch5.mp3";
			aSoundUrl["missleLaunch"] = "assets/sound/missleLaunch.mp3";
			aSoundUrl["shipExplosion"] = "assets/sound/shipExplosion.mp3";
			aSoundUrl["shipExplosion2"] = "assets/sound/shipExplosion2.mp3";
		}
		
		
		/**
		 * Renvoie l'url du sound en fonction de son id.
		 * 
		 */
		public function getSoundUrl(sId:String) : String
		{
			return aSoundUrl[sId];
		}

				
		
		/**
		 * Returns singleton instance of <code>Config</code> class.
		 * 
		 * @return The singleton instance of <code>Config</code> class.
		 */
		public static function getInstance() : Assets
		{
			// si l'instance n'existe pas, on la crée
			if ( !(Assets._oInstance is Assets) ) 
			{
				allowInstance = true;// autorise la création d'une instance
				Assets._oInstance = new Assets();
				allowInstance = false;// désactive la création d'autre instance
			}
			
			// renvoie toujours la même instance de la classe
			return Assets._oInstance;
		}
		
		
		/**
		 * Permet de récupérer une texture en fonction de sa classe.
		 * 
		 * @param name un identifiant qui correspond à une constant de type Bitmap.
		 * @return une texture starling.
		 */
		public function getTexture(name:String):Texture
		{
			if (sTextures[name] == undefined)
			{
				var loader:PXGraphicLoader = PXLoaderLocator.getInstance().getLoader(name) as PXGraphicLoader;
				var bitmap:Bitmap = loader.rawContent as Bitmap; 				
				sTextures[name] = Texture.fromBitmap(bitmap);// ajout d'une texture
			}

			return sTextures[name];
		}
		
		
		
		/**
		 * Renvoie le Bitmap utilisé pour créer la Texture.
		 * (utile pour la détection des collisions).
		 * 
		 */
		public function getBitmap(name:String) : Bitmap
		{
			var loader:PXGraphicLoader = PXLoaderLocator.getInstance().getLoader(name) as PXGraphicLoader;
			var bitmap:Bitmap = loader.rawContent as Bitmap; 
			return bitmap;				
		}


		
		/**
		 * Permet de récupérer un objet XML en fonction de sa classe.
		 * 
		 * @param name un identifiant qui correspond à une constante de type XML.
		 * @return un objet XML.
		 */
		public function getDataXml(name:String):XML
		{
			var loader:PXXMLLoader = PXLoaderLocator.getInstance().getLoader(name) as PXXMLLoader;
			return loader.xml;
		}
	}
}
